# pymusicterm Intallation

<!-- To install `pymusicterm`, it is recommended to use pip:
```
pip install pymusicterm
``` -->

You can install it from source. Clone this repository and use `pip` to install:
```
git clone https:
cd pymusicterm
pip install .
```

<!-- If `pymusicterm` is already installed and you would like to update it, use:
```
pip install --upgrade pymusicterm
``` -->

If updating local version, use:
```
cd pymusicterm
git pull
pip install --updgrade .
```

> *Note that you may require root acces for installing with `pip` depending on your system's python configuration*
